@@ -17,10 +17,6 @@ except ImportError:
         "You can do this by running `pip install -U dynamicprompts[magicprompt]`."
     )
 
-class DEVICE(Enum):
-    CPU = "cpu"
-    CUDA = "cuda:0"
-
 MODEL_NAME = "Gustavosta/MagicPrompt-Stable-Diffusion"
 MAX_SEED = 2 ** 32 - 1
 
@@ -38,7 +34,7 @@ class MagicPromptGenerator(PromptGenerator):
             MagicPromptGenerator.tokenizer = tokenizer
             MagicPromptGenerator.model = model
             MagicPromptGenerator.generator = pipeline(
-                task="text-generation", tokenizer=tokenizer, model=model, device=self._device.value
+                task="text-generation", tokenizer=tokenizer, model=model, device=self._device
             )
 
         return MagicPromptGenerator.generator
@@ -46,7 +42,7 @@ class MagicPromptGenerator(PromptGenerator):
     def __init__(
         self,
         prompt_generator: PromptGenerator,
-        device: DEVICE = DEVICE.CPU,
+        device: int,
         max_prompt_length: int = 100,
         temperature: float = 0.7,
         seed: int | None = None,
